# GPTCovLet
This takes in a job posting and some personal details then uses chatGPT to produce a human-like cover letter.

![Build Status](https://github.com/jaesungpark42/GPTCovLet/actions/workflows/build.yml/badge.svg)

[![codecov](https://codecov.io/gh/jaesungpark42/GPTCovLet/branch/main/graph/badge.svg?token=X5BN0AAOZ1)](https://codecov.io/gh/jaesungpark42/GPTCovLet)

# Overview
It's unreasonable for companies to mandate a cover letter when you are applying to many different ones. So this is to help streamline that process.


# Quickstart
pip install GPTCovLet
